<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">

<!--
SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.

SPDX-License-Identifier: LGPL-3.0-or-later
-->

<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1454"/>
        <source>%1 is released under %2</source>
        <translation>%1 é lançado sob a %2</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="869"/>
        <source>Black</source>
        <translation>Preto</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="872"/>
        <source>White</source>
        <translation>Branco</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="875"/>
        <source>Dark Gray</source>
        <translation>Cinza escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="878"/>
        <source>Gray</source>
        <translation>Cinza</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="881"/>
        <source>Light Gray</source>
        <translation>Cinza claro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="884"/>
        <source>Red</source>
        <translation>Vermelho</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="887"/>
        <source>Green</source>
        <translation>Verde</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="890"/>
        <source>Blue</source>
        <translation>Azul</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="893"/>
        <source>Cyan</source>
        <translation>Ciano</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="896"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="899"/>
        <source>Yellow</source>
        <translation>Amarelo</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="902"/>
        <source>Dark Red</source>
        <translation>Vermelho escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="905"/>
        <source>Dark Green</source>
        <translation>Verde escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="908"/>
        <source>Dark Blue</source>
        <translation>Azul escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="911"/>
        <source>Dark Cyan</source>
        <translation>Ciano escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="914"/>
        <source>Dark Magenta</source>
        <translation>Magenta escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="917"/>
        <source>Dark Yellow</source>
        <translation>Amarelo escuro</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="29"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="30"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>DKeySequenceEdit</name>
    <message>
        <location filename="../widgets/dkeysequenceedit.cpp" line="97"/>
        <source>Enter a new shortcut</source>
        <translation>Insira um novo atalho</translation>
    </message>
</context>
<context>
    <name>DLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="593"/>
        <source>Stop reading</source>
        <translation>Parar leitura</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="595"/>
        <source>Text to Speech</source>
        <translation>Texto para fala</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="618"/>
        <source>Translate</source>
        <translation>Traduzir</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="640"/>
        <source>Speech To Text</source>
        <translation>Fala para texto</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewDialogPrivate</name>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="278"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1268"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="301"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="302"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1647"/>
        <source>Print</source>
        <comment>button</comment>
        <translation>Imprimir</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="318"/>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="334"/>
        <source>Printer</source>
        <translation>Impressora</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="350"/>
        <source>Copies</source>
        <translation>Cópias</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="372"/>
        <source>Page range</source>
        <translation>Intervalo de páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="375"/>
        <source>All</source>
        <translation>Tudo</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="376"/>
        <source>Current page</source>
        <translation>Página atual</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="377"/>
        <source>Select pages</source>
        <translation>Selecionar páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="397"/>
        <source>Orientation</source>
        <translation>Orientação</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="422"/>
        <source>Portrait</source>
        <translation>Retrato</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="432"/>
        <source>Landscape</source>
        <translation>Paisagem</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="460"/>
        <source>Pages</source>
        <translation>Páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="472"/>
        <source>Color mode</source>
        <translation>Modo de cor</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="475"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1583"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1663"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1679"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1694"/>
        <source>Color</source>
        <translation type="vanished">Cor</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="475"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1670"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1682"/>
        <source>Grayscale</source>
        <translation>Escala cinza</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="487"/>
        <source>Margins</source>
        <translation>Margens</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Narrow (mm)</source>
        <translation>Estreita (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Normal (mm)</source>
        <translation>Normal (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Moderate (mm)</source>
        <translation>Moderada (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Customize (mm)</source>
        <translation>Personalizada (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="500"/>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="503"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="506"/>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="509"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="556"/>
        <source>Scaling</source>
        <translation>Dimensionamento</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="573"/>
        <source>Actual size</source>
        <translation>Tamanho atual</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="582"/>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="613"/>
        <source>Paper</source>
        <translation>Papel</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="626"/>
        <source>Paper size</source>
        <translation>Tamanho do papel</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="641"/>
        <source>Print Layout</source>
        <translation>Layout de impressão</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="655"/>
        <source>Duplex</source>
        <translation>Frente e verso</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="668"/>
        <source>N-up printing</source>
        <translation>Impressão N em 1</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>2 pages/sheet, 1×2</source>
        <translation>2 páginas/folha, 1×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>4 pages/sheet, 2×2</source>
        <translation>4 páginas/folha, 2×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>6 pages/sheet, 2×3</source>
        <translation>6 páginas/folha, 2×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>9 pages/sheet, 3×3</source>
        <translation>9 páginas/folha, 3×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>16 pages/sheet, 4×4</source>
        <translation>16 páginas/folha, 4×4</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="683"/>
        <source>Layout direction</source>
        <translation>Orientação do layout</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="727"/>
        <source>Page Order</source>
        <translation>Ordem das páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="740"/>
        <source>Collate pages</source>
        <translation>Agrupar páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="746"/>
        <source>Print pages in order</source>
        <translation>Imprimir páginas em ordem</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
        <source>Front to back</source>
        <translation>Frente para trás</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
        <source>Back to front</source>
        <translation>Trás para frente</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="774"/>
        <source>Watermark</source>
        <translation>Marca d&apos;água</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="788"/>
        <source>Add watermark</source>
        <translation>Adicionar marca d&apos;água</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="834"/>
        <source>Text watermark</source>
        <translation>Marca d&apos;água de texto</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Confidential</source>
        <translation>Confidencial</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Draft</source>
        <translation>Rascunho</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Sample</source>
        <translation>Amostra</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="847"/>
        <source>Input your text</source>
        <translation>Insira seu texto</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="872"/>
        <source>Picture watermark</source>
        <translation>Marca d&apos;água de imagem</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="896"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="899"/>
        <source>Tile</source>
        <translation>Ladrilho</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="899"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="912"/>
        <source>Angle</source>
        <translation>Ângulo</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="931"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="955"/>
        <source>Transparency</source>
        <translation>Transparência</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1013"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2283"/>
        <source>Print to PDF</source>
        <translation>Imprimir para PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1014"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2282"/>
        <source>Save as Image</source>
        <translation>Salvar como imagem</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1264"/>
        <source>Collapse</source>
        <translation>Recolher</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1359"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1368"/>
        <source>Flip on short edge</source>
        <translation>Virar pela borda curta</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1298"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1363"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1367"/>
        <source>Flip on long edge</source>
        <translation>Virar pela borda longa</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1461"/>
        <source>Input page numbers please</source>
        <translation>Insira os números das páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1464"/>
        <source>Maximum page number reached</source>
        <translation>Número máximo de páginas atingido</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1467"/>
        <source>Input English comma please</source>
        <translation>Insira a vírgula</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1470"/>
        <source>Input page numbers like this: 1,3,5-7,11-15,18,21</source>
        <translation>Insira os números das páginas: 1, 3, 5-7, 11-15, 18, 21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1700"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvar</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2312"/>
        <source>*.pdf</source>
        <translation>*.pdf</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1770"/>
        <source>For example, 1,3,5-7,11-15,18,21</source>
        <translation>Por exemplo: 1, 3, 5-7, 11-15, 18, 21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2312"/>
        <source>Save as PDF</source>
        <translation>Salvar como PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2351"/>
        <source>Save as image</source>
        <translation>Salvar como imagem</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2353"/>
        <source>Images</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <source>Full Color</source>
        <translation>Colorido</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewWidget</name>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1590"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1593"/>
        <source>Confidential</source>
        <translation>Confidencial</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1608"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1611"/>
        <source>Draft</source>
        <translation>Rascunho</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1626"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1629"/>
        <source>Sample</source>
        <translation>Amostra</translation>
    </message>
</context>
<context>
    <name>DSearchEdit</name>
    <message>
        <location filename="../widgets/dsearchedit.cpp" line="286"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>DSettingsDialog</name>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="66"/>
        <source>Replace</source>
        <translation>Substituir</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="68"/>
        <source>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</source>
        <translation>Este atalho entra em conflito com %1. Clique em Adicionar para efetivar este atalho</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="18"/>
        <source>Please input a new shortcut</source>
        <translation>Insira um novo atalho</translation>
    </message>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="89"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
</context>
<context>
    <name>DTextEdit</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="202"/>
        <source>Stop reading</source>
        <translation>Parar leitura</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="204"/>
        <source>Text to Speech</source>
        <translation>Texto para fala</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="227"/>
        <source>Translate</source>
        <translation>Traduzir</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="249"/>
        <source>Speech To Text</source>
        <translation>Fala para texto</translation>
    </message>
</context>
<context>
    <name>DToolbarEditPanel</name>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="884"/>
        <source>Default toolset</source>
        <translation>Conjunto de ferramentas padrão</translation>
    </message>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="915"/>
        <source>Drag your favorite items into the toolbar</source>
        <translation>Arraste seus itens favoritos para a barra de ferramentas</translation>
    </message>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="916"/>
        <source>Drag below items into the toolbar to restore defaults</source>
        <translation>Arraste os itens abaixo para a barra de ferramentas para restaurar os padrões</translation>
    </message>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="921"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>PickColorWidget</name>
    <message>
        <location filename="../widgets/dprintpickcolorwidget.cpp" line="94"/>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="526"/>
        <source>&amp;Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="529"/>
        <source>Cu&amp;t</source>
        <translation>Recortar</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="534"/>
        <source>Select All</source>
        <translation>Selecionar tudo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/dsimplelistview.cpp" line="1347"/>
        <source>No search result</source>
        <translation>Nenhum resultado encontrado</translation>
    </message>
    <message>
        <location filename="../widgets/private/settings/content.cpp" line="330"/>
        <source>Restore Defaults</source>
        <translation>Restaurar padrões</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="108"/>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="110"/>
        <source>Features</source>
        <translation>Recursos</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="122"/>
        <source>Homepage</source>
        <translation>Página web</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="124"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="126"/>
        <source>Acknowledgements</source>
        <translation>Agradecimentos</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="128"/>
        <location filename="../widgets/daboutdialog.cpp" line="393"/>
        <source>Sincerely appreciate the open-source software used.</source>
        <translation>Agradecemos sinceramente pelo software de código aberto utilizado.</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="395"/>
        <source>open-source software</source>
        <translation>Software de código aberto</translation>
    </message>
    <message>
        <location filename="../widgets/dfeaturedisplaydialog.cpp" line="151"/>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="../widgets/dfeaturedisplaydialog.cpp" line="175"/>
        <source>Learn More</source>
        <translation>Saiba mais</translation>
    </message>
    <message>
        <location filename="../widgets/dlicensedialog.cpp" line="78"/>
        <source>Open-Source Software</source>
        <translation>Software de código aberto</translation>
    </message>
</context>
<context>
    <name>QWidgetTextControl</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="194"/>
        <source>Select All</source>
        <translation>Selecionar tudo</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../widgets/private/settings/shortcutedit.cpp" line="104"/>
        <source>Please enter a new shortcut</source>
        <translation>Insira um novo atalho</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="634"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="636"/>
        <source>Light Theme</source>
        <translation>Claro</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="637"/>
        <source>Dark Theme</source>
        <translation>Escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="638"/>
        <source>System Theme</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="668"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="676"/>
        <source>Feedback</source>
        <translation>Feedback</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="683"/>
        <source>Custom toolbar</source>
        <translation>Barra de ferramentas personalizada</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="691"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="698"/>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
</TS>